@@ -2,12 +2,10 @@ use strict;
 use warnings;
 
 package Data::SUID;
-our $VERSION = '2.0.1'; # VERSION
-use threads;
-use threads::shared;
+our $VERSION = '2.0.2'; # VERSION
 use Crypt::Random          ( 'makerandom' );
 use Exporter               ();
-use Net::Address::Ethernet ();
+use Net::Address::Ethernet ( 'get_address' );
 use Math::BigInt try => 'GMP';
 use Readonly;
 use namespace::clean;
@@ -59,27 +57,31 @@ sub binary
 sub suid { __PACKAGE__->new( @_ ) }
 
 {
-    my @ident : shared;
-    my $ident : shared;
-    lock @ident;
-    lock $ident;
-    # Don't want the 24-bit OUID!
-    @ident = +( map 0 + $_, Net::Address::Ethernet::get_address() )[ 3, 4, 5 ];
-    $ident = sprintf( '%02x%02x%02x', @ident );
+    my @ident;
+    my $ident;
 
-    sub _machine_ident { wantarray ? @ident : $ident }
+    sub _machine_ident
+    {
+        my (undef, @bytes) = @_;
+        @ident = map 0 + ( $_ || 0 ), @bytes[ 0, 1, 3 ]
+            if @_;
+        @ident = +( map 0 + ( $_ || 0 ), get_address() )[ 3, 4, 5 ]
+            unless @ident;
+        $ident = sprintf( '%02x%02x%02x', @ident )
+            unless $ident;
+        return wantarray ? @ident : $ident;
+    }
 }
 
 {
-    my $count_width    = 24;
-    my $count_mask     = 2**$count_width - 1;
-    my $count_format   = '%0' . int( $count_width / 4 ) . 'x';
-    my $count : shared = undef;
+    my $count_width  = 24;
+    my $count_mask   = 2**$count_width - 1;
+    my $count_format = '%0' . int( $count_width / 4 ) . 'x';
+    my $count        = undef;
 
     sub _reset_count
     {
         my ( $class, $value ) = @_;
-        lock $count;
         $count = $count_mask & ( 0 + abs( $value ) )
             if defined $value;
         unless ( defined $count ) {
@@ -96,7 +98,6 @@ sub suid { __PACKAGE__->new( @_ ) }
     {
         &_reset_count unless defined $count;
         my $result = sprintf( $count_format, $count );
-        lock $count;
         $count = $count_mask & ( 1 + $count );
         return $result;
     }
@@ -110,11 +111,11 @@ sub suid { __PACKAGE__->new( @_ ) }
 
 =head1 NAME
 
-Data::SUID - Generates thread-safe sequential unique ids
+Data::SUID - Generates sequential unique ids
 
 =head1 VERSION
 
-version 2.0.1
+version 2.0.2
 
 =head1 SYNOPSIS
 
@@ -140,12 +141,12 @@ version 2.0.1
 
 =head1 DESCRIPTION
 
-Use this package to generate thread-safe 12-byte sequential unique ids
-modeled upon the MongoDB BSON ObjectId. Unlike traditional GUIDs, these
-are somewhat more index-friendly and reasonably suited for use as
-primary keys within database tables. They are guaranteed to have a high
-level of uniqueness, given that they contain a timestamp, a host identifier
-and an incremented sequence number.
+Use this package to generate 12-byte sequential unique ids modeled upon 
+Mongo's BSON ObjectId. Unlike traditional GUIDs, these are somewhat more 
+index-friendly and reasonably suited for use as primary keys within database 
+tables. They are guaranteed to have a high level of uniqueness, given that
+they contain a timestamp, a host identifier and an incremented sequence
+number.
 
 =head1 METHODS
 
